@@ -3,6 +3,5 @@ from whisper_evaluate.whisper_statistics import WhisperStatistics
 from whisper_evaluate.netease_statistics import NetEaseStatistics
 from whisper_evaluate.report import Report
 from whisper_evaluate.utils import context_test_single, regression_test_single
-from whisper_evaluate.aio_query import WhisperQuery
-
-
+from whisper_evaluate.aio_query import WhisperQuery, NeteaseQuery
+from whisper_evaluate.compares import compare_yidun_whisper_results, parse_whisper_json, parse_yidun_json
