@@ -119,7 +119,7 @@ class NetEaseStatistics(Statistics):
         x = x.replace("'", '"').replace("\\x0", "")
         a = json.loads(x)
         data = a["result"]
-        _type = self.id2label[data['labels'][0]['label']] if data['labels'] else '其他'
+        _type = self.id2label[data['labels'][0]['label']] if data['labels'] else '健康'
         _hint = " ".join(data['labels'][0]['details']['hint'] if data['labels'] else [])
         predict_label_review2pass = self.level_review_as_pass[data['labels'][0]['level']] if data['labels'] else 'Pass'
         predict_label_review2reject = self.level_review_as_reject[data['labels'][0]['level']] if data[
@@ -137,7 +137,7 @@ class NetEaseStatistics(Statistics):
                 a = json.loads(line)
                 text = a['text']
                 data = a['details'][0]['data']
-                _label = self.id2label[data['labels'][0]['label']] if data['labels'] else '其他'
+                _label = self.id2label[data['labels'][0]['label']] if data['labels'] else '健康'
                 _level = self.level[data['labels'][0]['level']] if data['labels'] else 'Pass'
                 _hint = data['labels'][0]['details']['hint'] if data['labels'] else []
                 text2result[text] = [_level.strip(), _label.strip(), " ".join(_hint)]
